Index: /trunk/src/VBox/Devices/Audio/DevIchAc97.cpp
===================================================================
--- /trunk/src/VBox/Devices/Audio/DevIchAc97.cpp	(revision 62279)
+++ /trunk/src/VBox/Devices/Audio/DevIchAc97.cpp	(revision 62280)
@@ -984,8 +984,8 @@
     rCntlAtt   = uVal & AC97_BARS_VOL_MASK;
 
     /* For the master volume, 0 corresponds to 0dB attenuation. For the other volume
      * controls, 0 means 12dB gain and 8 means unity gain. 
      */
-    if (index != AC97_Master_Volume_Mute)
+    if (index != AC97_Master_Volume_Mute && index != AC97_Headphone_Volume_Mute)
     {
 #ifndef VBOX_WITH_AC97_GAIN_SUPPORT
@@ -1002,6 +1002,6 @@
 
     /*
-     * For AC'97 volume controls, each additional step means -1.5dB attenuation with 
-     * zero being maximum. In contrast, we're internally using 255 (PDMAUDIO_VOLUME_MAX) 
+     * For AC'97 volume controls, each additional step means -1.5dB attenuation with
+     * zero being maximum. In contrast, we're internally using 255 (PDMAUDIO_VOLUME_MAX)
      * steps, each -0.375dB, where 0 corresponds to -96dB and 255 corresponds to 0dB.
      */
@@ -984,8 +984,8 @@
     rCntlAtt   = uVal & AC97_BARS_VOL_MASK;
 
-    /* For the master volume, 0 corresponds to 0dB attenuation. For the other volume
-     * controls, 0 means 12dB gain and 8 means unity gain. 
+    /* For the master and headphone volume, 0 corresponds to 0dB attenuation. For the other
+     * volume controls, 0 means 12dB gain and 8 means unity gain.
      */
